@@ -1,4 +1,7 @@
-	sitar <- function(x, y, id, data, df, knots, fixed=random, random='a+b+c', a.formula=~1, b.formula=~1, c.formula=~1, bounds=0.04, start, bstart='mean', xoffset='mean', returndata=FALSE, verbose=FALSE, correlation=NULL, weights=NULL, subset=NULL, method='ML', na.action=na.fail, control = nlmeControl(returnObject=TRUE), newform=TRUE)
+	sitar <- function(x, y, id, data, df, knots, fixed=random, random='a+b+c',
+	                  a.formula=~1, b.formula=~1, c.formula=~1, bounds=0.04, start, bstart=xoffset, xoffset='mean',
+	                  returndata=FALSE, verbose=FALSE, correlation=NULL, weights=NULL, subset=NULL, method='ML',
+	                  na.action=na.fail, control = nlmeControl(returnObject=TRUE))
 #
 #	fit growth curves of y ~ ns(f(x)) by id
 #	df - number of knots (or length of knots + 1)
@@ -10,14 +13,11 @@
 #	bounds - span of ns, default x-range 4%
 #	start - starting values - default estimated
 #			requires spline coefficients, any missing zeroes added
-#	bstart - starting value for b, default 'mean', or 'apv' or value
-#		(subsumes xoffset)
+#	bstart - starting value for b, default xoffset
 #	xoffset - offset for x, default 'mean', alternatives 'apv' or value
 # returndata - if TRUE returns nlme data frame, not nlme model
 #	verbose etc - arguments passed to nlme
 
-#	newform - FALSE uses xoffset, TRUE uses bstart
-
 #	returns call, ns, nlme.out if returndata FALSE
 #			else fulldata
 {
@@ -30,45 +30,41 @@
 		if (!is.numeric(b)) stop('must be "mean" or "apv" or numeric')
 		b
 	}
+
+# get data
 	mcall <- match.call()
 	data <- eval(mcall$data, parent.frame())
 	x <- eval(mcall$x, data)
 	y <- eval(mcall$y, data)
+	xoffset <- b.origin(xoffset)
+	x <- x - xoffset
+
+# get df, knots and bounds
 	if (missing(df) & missing(knots)) stop("either df or knots must be specified")
 	if (!missing(df) & !missing(knots)) cat("both df and knots specified - df redefined from knots\n")
-	if (missing(knots)) knots <- quantile(x, (1:(df-1))/df)
-		else df <- length(knots) + 1
+	if (missing(knots)) knots <- quantile(x, (1:(df-1))/df) else {
+	  knots <- knots - xoffset
+	  df <- length(knots) + 1
+	}
 	if (nrow(data) <= df) stop("too few data to fit spline curve")
-#	define bounds, default x range 4%
 	if (length(bounds) == 1) bounds <- range(x) + abs(bounds) * c(-1,1) * diff(range(x))
-	if (length(bounds) != 2) stop("bounds should be length 1 or 2")
-#	derive x variable offset
-	if (newform || !missing(bstart)) { # using bstart
-		newform <- TRUE
-		mcall$xoffset <- NULL
-		if (b.formula == as.formula('~ -1') || b.formula == as.formula('~ 1-1') || !grepl('b', fixed)) bstart <- 0
-		else bstart <- b.origin(bstart)
-		knots <- knots - mean(x)
-		bounds <- bounds - mean(x)
+	else if (length(bounds) == 2) bounds <- bounds - xoffset
+	else stop("bounds should be length 1 or 2")
+
 #	get spline start values
-		spline.lm <- lm(y ~ ns(x - mean(x), knots=knots, Bound=bounds))
-	}
-	else { # using xoffset
-		xoffset <- b.origin(xoffset)
-#	apply xoffset
-		x <- x - xoffset
-		knots <- knots - xoffset
-		bounds <- bounds - xoffset
-#	get spline start values
-		spline.lm <- lm(y ~ ns(x, knots=knots, Bound=bounds))
-	}
-#	get starting values for ss and a
+	spline.lm <- lm(y ~ ns(x, knots=knots, Bound=bounds))
+
+#	get starting values for ss, a and b
 	if (missing(start)) start <- coef(spline.lm)[c(2:(df+1), 1)]
+
 #	force fixed effect for a
 	fix <- fixed
 	if (!grepl('a', fix)) fix <- paste('a', fix, sep='+')
+
+# set up args for fitnlme
 	fixed <- ss <- paste('s', 1:df, sep='')
 	pars <- c('x', ss)
+
 #	set up model elements for a, b and c
 	names(model) <- model <- letters[1:3]
 	constant <- mm.formula <- as.formula('~ 1')
@@ -121,12 +117,9 @@
 		}
 		if (mm.intercept) {
 			fixed <- c(fixed, l)
-			if (!is.list(start)) {
-				if (newform) {
-					if (l == 'b') start <- c(start, bstart)
-					else if (l == 'c') start <- c(start, 0)
-				}
-				else if (l != 'a') start <- c(start, 0)
+			if (!is.list(start) && l != 'a') {
+			  if (l == 'b') start <- c(start, b.origin(bstart) - xoffset)
+			    else start <- c(start, 0)
 			}
 		}
 	}
@@ -148,12 +141,12 @@
 		fixed <- paste(fixed, collapse='+')
 		sscomma <- paste(ss, collapse=',')
 
-	#	combine model elements
+#	combine model elements
 		nsd <- paste(model['a'], '+')
 		nsf <- paste('(x', ifelse(!is.na(model['b']), paste('- (', model['b'], '))'), ')'))
 		if (!is.na(model['c'])) nsf <- paste(nsf, '* exp(', model['c'], ')')
 
-	#	code to parse
+#	code to parse
   	fitcode <- c(
 	"fitenv <- new.env()",
 	"fitenv$fitnlme <- function($pars) {",
@@ -175,7 +168,7 @@
 		for (i in c('random', 'pars', 'fixed', 'sscomma', 'nsd', 'nsf'))
   		fitcode <- gsub(paste('$', i, sep=''), get(i), fitcode, fixed=TRUE)
 
-	#	print values
+#	print values
 		if (verbose) {
 			cat('\nconstructed code', fitcode, sep='\n')
 			cat('\ndf', df, 'bstart', bstart, 'xoffset', xoffset, '\nknots\n', knots, '\nbounds\n', bounds)
@@ -189,13 +182,12 @@
 			else cat('\nstarting values\n', start, '\n')
 		}
 
-	#	save fitted model
+#	save fitted model
     nlme.out <- eval(parse(text=fitcode))
 #     if (exists('start.')) rm(start., inherits=TRUE)
     nlme.out$fitnlme <- fitenv$fitnlme
 		nlme.out$call.sitar <- mcall
-		if (newform) nlme.out$bstart <- bstart
-			else nlme.out$xoffset <- xoffset
+		nlme.out$xoffset <- xoffset
 		nlme.out$ns <- spline.lm
 		if (!'sitar' %in% class(nlme.out)) class(nlme.out) <- c('sitar', class(nlme.out))
 		nlme.out
