@@ -9,6 +9,14 @@
 	for (i in names(extras))
 		if (is.null(extras[[i]]))
 			mcall[[i]] <- extras[[i]] <- NULL
+#	expand formulae
+	if (any(grep('formula', names(extras)))) {
+    for (a in letters[1:3]) {
+      n <- paste(a, 'formula', sep='.')
+      if (!is.null(extras[[n]]) && !is.null(mcall[[n]]))
+        extras[[n]] <-  update.formula(mcall[[n]], extras[[n]])
+    }
+  }
 # update args
 	mcall[names(extras)] <- extras
 #	add start arg if none of these args specified
@@ -16,12 +24,15 @@
 	                                "c.formula", "start", "returndata"), 0))) {
   	start. <- list(fixed=fixef(object), random=ranef(object))
 # update start if any of these args specified
-  	if (sum(pmatch(names(extras), c('data', 'subset', 'df', 'knots', 'bounds', 'bstart'), 0))) {
+  	if (sum(pmatch(names(extras), c('data', 'subset', 'df', 'knots', 'bounds', 'xoffset', 'bstart'), 0))) {
 # get data etc
   		data <- eval(mcall$data)
   		subset <- eval(mcall$subset, data)
   		if (!is.null(subset)) data <- data[subset, ]
   		x <- eval(mcall$x, data)
+  		xoffset <- object$xoffset
+  		if (is.null(xoffset)) xoffset <- mean(x)
+  		x <- x - xoffset
   		df <- object$ns$rank - 1
   		knots <- attr(object$ns$model$ns, 'knots')
   		bounds <- attr(object$ns$model$ns, 'Boundary.knots')
@@ -36,7 +47,8 @@
 #	add zero random effects for new levels in id
   		    newid <- !levels(id) %in% levels.obj
   		    if (sum(newid) > 0) {
-  		      newre <- matrix(0, nrow=sum(newid), ncol=dim(ranef(object))[2], dimnames=list(levels(id)[newid], dimnames(ranef(object))[[2]]))
+  		      newre <- matrix(0, nrow=sum(newid), ncol=dim(ranef(object))[2],
+  		                      dimnames=list(levels(id)[newid], dimnames(ranef(object))[[2]]))
   		      start.$random <- rbind(start.$random, newre)
   		      cat(sum(newid), 'subjects added\n')
   		    }
@@ -45,37 +57,47 @@
 #	update fixed effects
   		if (length(fixef(object)) > df + 1) fixed.extra <- (df+2):length(fixef(object))
   			else fixed.extra <- NULL
+# new arg xoffset
+  		if (!is.null(extras$xoffset)) {
+  		  xoffset.t <- xoffset
+  		  xoffset <- extras$xoffset
+  		  xoffset.t <- xoffset - xoffset.t
+  		  x <- x - xoffset.t
+  		  knots <- knots - xoffset.t
+  		  bounds <- bounds - xoffset.t
+  		}
 # new arg knots
   		if (!is.null(extras$knots)) {
-  			knots <- eval(extras$knots) - mean(x)
+  			knots <- eval(extras$knots) - xoffset
   			df <- length(knots) + 1
   			mcall$df <- NULL
   		}
 # new arg df
   		else if (!is.null(extras$df)) {
-  			df <- eval(extras$df)
-  			knots <- quantile(x, (1:(df-1))/df) - mean(x)
+  			df <- extras$df
+  			knots <- quantile(x, (1:(df-1))/df)
   			mcall$knots <- NULL
   		}
 # new arg bounds
   		if (!is.null(extras$bounds)) {
   			bounds <- eval(extras$bounds)
   			if (length(bounds) == 1) bounds <- range(x) + abs(bounds) * c(-1,1) * diff(range(x))
-  			bounds <- bounds - mean(x)
+  			  else bounds <- bounds - xoffset
   		}
+#	get spline start values
+  		spline.lm <- lm(predict(object, data, level=0) ~ ns(x, knots=knots, Bound=bounds))
+  		start.$fixed <- c(coef(spline.lm)[c(2:(df+1), 1)], start.$fixed[fixed.extra])
 # new arg bstart
   		if (!is.null(extras$bstart) && !is.null(start.$fixed['b'])) {
   			bstart <- eval(extras$bstart)
-  			if (is.character(bstart)) bstart <- mean(x)
+  			if (bstart == 'mean') bstart <- mean(x)
+  			  else bstart <- bstart - xoffset
   			start.$fixed['b'] <- bstart
   		}
-#	get spline start values
-  		spline.lm <- lm(predict(object, data, level=0) ~ ns(x - mean(x), knots=knots, Bound=bounds))
-  		start.$fixed <- c(coef(spline.lm)[c(2:(df+1), 1)], start.$fixed[fixed.extra])
   	}
 #	save start. object
 		assign('start.', start., parent.frame())
-		mcall <- as.call(c(as.list(mcall), start=quote(start.)))
+		mcall[['start']] <- quote(start.)
 	}
 	if (evaluate)
 		eval(mcall, parent.frame())
